/**
 * @file Resolvers pour tous les types de messages.
 */
import * as connectors from '../connectors/connectors';

const MessageResolvers = {
    Message: {

        __resolveType: function(obj) {
            return obj.type;

        }
    },

    Announcement: {
        forEvent : function(obj, args, context){
            // le champ is_announcement n'existe que sur les Events
            // une ligne de la bdd events peut résoudre comme évènement ou comme annonce
            if(obj.is_announcement) 
                return obj;
            else
                return null;
        },

        authors: async function (obj, args, context){
            return connectors.getMessageGroupAuthors(context.user, obj.id);
        },

        recipients: async function (obj, args, context){
            return connectors.getMessageGroupRecipients(context.user, obj.id);
        },

    },

    Event: {

        startTime: function (obj) {
            return obj.start_time;
        },

        endTime: function (obj) {
            return obj.end_time;
        },

        asAnnouncement: function (obj, args, context) {
            // le champ is_announcement indique si il existe une annonce qui va avec l'évènement
            // une ligne de la bdd events peut résoudre comme évènement ou comme annonce
            if (obj.is_announcement)
                return obj;
            else
                return null;
        },

        authors: async function (obj, args, context) {
            return connectors.getMessageGroupAuthors(context.user, obj.id);
        },

        recipients: async function (obj, args, context) {
            return connectors.getMessageGroupRecipients(context.user, obj.id);
        }
    },



    PrivatePost : {

        authors: async function(obj, args, context){
            return connectors.getUser(context.user, obj.author_uid, obj.author_db);
            
        },

        recipients: async function(obj, args, context){
            return connectors.getGroup(context.user, obj.recipient_uid);
            
        }
    },

    Question : {

        authors: async function(obj, args, context){
            return connectors.getUser(context.user, obj.author_uid, obj.author_db);
        },

        recipients: async function(obj, args, context){
            return connectors.getGroup(context.user, obj.recipient_uid);
        },

        forAnswer: function(obj, args, context){
            return obj.for_answer;
        }
    },

    Answer : {

        authors: async function(obj, args, context){
            return connectors.getGroup(context.user, obj.author_uid);
        },

        recipients: async function(obj, args, context){
            return connectors.getGroup(context.user, obj.recipient_uid);
        },

        forQuestion: function(obj, args, context){
            return obj.for_question;

        },
    }
};

export default MessageResolvers;